/*
 * Copyright (C) 2022 Intel Corporation
 *
 * SPDX-License-Identifier: MIT
 *
 */

#pragma once

#define BUILD_VERSION "npu-linux-driver-dev-1.35.0.dev-0"

const char vpu_drv_version_str[] = BUILD_VERSION;
